@@ -8,6 +8,8 @@
 #
 # See the LICENSE file in the source distribution for further information.
 
+# pylint: disable=too-many-locals,too-many-branches
+
 import fnmatch
 import inspect
 import json
@@ -23,7 +25,7 @@ from datetime import datetime
 from concurrent.futures import ThreadPoolExecutor
 from getpass import getpass
 from pathlib import Path
-from pipes import quote
+from shlex import quote
 from textwrap import fill
 from sos.cleaner import SoSCleaner
 from sos.collector.sosnode import SosNode
@@ -87,6 +89,7 @@ class SoSCollector(SoSComponent):
         'group': None,
         'image': '',
         'force_pull_image': True,
+        'skip_cleaning_files': [],
         'jobs': 4,
         'journal_size': 0,
         'keywords': [],
@@ -134,11 +137,17 @@ class SoSCollector(SoSComponent):
         'upload_pass': None,
         'upload_method': 'auto',
         'upload_no_ssl_verify': False,
-        'upload_protocol': 'auto'
+        'upload_protocol': 'auto',
+        'upload_s3_endpoint': None,
+        'upload_s3_region': None,
+        'upload_s3_bucket': None,
+        'upload_s3_access_key': None,
+        'upload_s3_secret_key': None,
+        'upload_s3_object_prefix': None
     }
 
     def __init__(self, parser, parsed_args, cmdline_args):
-        super(SoSCollector, self).__init__(parser, parsed_args, cmdline_args)
+        super().__init__(parser, parsed_args, cmdline_args)
         os.umask(0o77)
         self.client_list = []
         self.node_list = []
@@ -160,9 +169,9 @@ class SoSCollector(SoSComponent):
         # get the local hostname and addresses to filter from results later
         self.hostname = socket.gethostname()
         try:
-            self.ip_addrs = list(set([
+            self.ip_addrs = list({
                 i[4][0] for i in socket.getaddrinfo(socket.gethostname(), None)
-            ]))
+            })
         except Exception:
             # this is almost always a DNS issue with reverse resolution
             # set a safe fallback and log the issue
@@ -179,15 +188,13 @@ class SoSCollector(SoSComponent):
             try:
                 self.parse_node_strings()
                 self.parse_cluster_options()
-                self.log_debug('Executing %s' % ' '.join(s for s in sys.argv))
-                self.log_debug("Found cluster profiles: %s"
-                               % self.clusters.keys())
+                self.log_debug(f'Executing {" ".join(s for s in sys.argv)}')
+                self.log_debug(
+                    f"Found cluster profiles: {self.clusters.keys()}")
                 self.verify_cluster_options()
 
             except KeyboardInterrupt:
                 self.exit('Exiting on user cancel', 130)
-            except Exception:
-                raise
 
     def load_clusters(self):
         """Loads all cluster types supported by the local installation for
@@ -228,18 +235,23 @@ class SoSCollector(SoSComponent):
                     continue
                 if '__' in pyfile:
                     continue
-                fname, ext = os.path.splitext(pyfile)
-                modname = 'sos.collector.%s.%s' % (modulename, fname)
+                fname, _ = os.path.splitext(pyfile)
+                modname = f'sos.collector.{modulename}.{fname}'
                 modules.extend(cls._import_modules(modname))
         return modules
 
     @classmethod
-    def _import_modules(self, modname):
+    def _import_modules(cls, modname):
         """Import and return all found classes in a module"""
         mod_short_name = modname.split('.')[2]
-        module = __import__(modname, globals(), locals(), [mod_short_name])
+        try:
+            module = __import__(modname, globals(), locals(), [mod_short_name])
+        except ImportError as e:
+            print(f'Error while trying to load module {modname}: '
+                  f' {e.__class__.__name__}')
+            raise e
         modules = inspect.getmembers(module, inspect.isclass)
-        for mod in modules:
+        for mod in modules.copy():
             if mod[0] in ('SosHost', 'Cluster'):
                 modules.remove(mod)
         return modules
@@ -292,7 +304,7 @@ class SoSCollector(SoSComponent):
                              help='Collect logs regardless of size')
         sos_grp.add_argument('--allow-system-changes', action='store_true',
                              default=False,
-                             help=('Allow sosreport to run commands that may '
+                             help=('Allow sos report to run commands that may '
                                    'alter system state'))
         sos_grp.add_argument('--chroot', default='',
                              choices=['auto', 'always', 'never'],
@@ -301,7 +313,7 @@ class SoSCollector(SoSComponent):
                              help="Default container runtime to use for "
                                   "collections. 'auto' for policy control.")
         sos_grp.add_argument('-e', '--enable-plugins', action="extend",
-                             help='Enable specific plugins for sosreport')
+                             help='Enable specific plugins for sos report')
         sos_grp.add_argument('--journal-size', type=int, default=0,
                              help='Limit the size of journals in MiB')
         sos_grp.add_argument('-k', '--plugin-option', '--plugopts',
@@ -322,7 +334,7 @@ class SoSCollector(SoSComponent):
                                   'output for - 0 means unlimited')
         sos_grp.add_argument('--no-env-vars', action='store_true',
                              default=False,
-                             help='Do not collect env vars in sosreports')
+                             help='Do not collect env vars in sos reports')
         sos_grp.add_argument('--plugin-timeout', type=int, default=None,
                              help='Set the global plugin timeout value')
         sos_grp.add_argument('--cmd-timeout', type=int, default=None,
@@ -413,7 +425,7 @@ class SoSCollector(SoSComponent):
         collect_grp.add_argument('--ssh-user',
                                  help='Specify an SSH user. Default root')
         collect_grp.add_argument('--timeout', type=int, required=False,
-                                 help='Timeout for sosreport on each node.')
+                                 help='Timeout for sos report on each node.')
         collect_grp.add_argument('--transport', default='auto', type=str,
                                  help='Remote connection transport to use')
         collect_grp.add_argument("--upload", action="store_true",
@@ -435,8 +447,21 @@ class SoSCollector(SoSComponent):
                                  action='store_true',
                                  help="Disable SSL verification for upload url"
                                  )
+        collect_grp.add_argument("--upload-s3-endpoint", default=None,
+                                 help="Endpoint to upload to for S3 bucket")
+        collect_grp.add_argument("--upload-s3-region", default=None,
+                                 help="Region for the S3 bucket")
+        collect_grp.add_argument("--upload-s3-bucket", default=None,
+                                 help="Name of the S3 bucket to upload to")
+        collect_grp.add_argument("--upload-s3-access-key", default=None,
+                                 help="Access key for the S3 bucket")
+        collect_grp.add_argument("--upload-s3-secret-key", default=None,
+                                 help="Secret key for the S3 bucket")
+        collect_grp.add_argument("--upload-s3-object-prefix", default=None,
+                                 help="Prefix for the S3 object/key")
         collect_grp.add_argument("--upload-protocol", default='auto',
-                                 choices=['auto', 'https', 'ftp', 'sftp'],
+                                 choices=['auto', 'https', 'ftp', 'sftp',
+                                          's3'],
                                  help="Manually specify the upload protocol")
 
         # Group the cleaner options together
@@ -459,6 +484,11 @@ class SoSCollector(SoSComponent):
                                  default=[], dest='disable_parsers',
                                  help=('Disable specific parsers, so that '
                                        'those elements are not obfuscated'))
+        cleaner_grp.add_argument('--skip-cleaning-files',
+                                 '--skip-masking-files', action='extend',
+                                 default=[], dest='skip_cleaning_files',
+                                 help=('List of files to skip/ignore during '
+                                       'cleaning. Globs are supported.'))
         cleaner_grp.add_argument('--keywords', action='extend', default=[],
                                  dest='keywords',
                                  help='List of keywords to obfuscate')
@@ -490,9 +520,9 @@ class SoSCollector(SoSComponent):
         section.add_text(
             'The following help sections may be of further interest:\n'
         )
-        for hsec in hsections:
+        for hsec, value in hsections.items():
             section.add_text(
-                "{:>8}{:<40}{:<30}".format(' ', bold(hsec), hsections[hsec]),
+                f"{' ':>8}{bold(hsec):<40}{value:<30}",
                 newline=False
             )
 
@@ -516,7 +546,7 @@ class SoSCollector(SoSComponent):
         try:
             self.close_all_connections()
         except Exception:
-            pass
+            self.log_warn("Warning: Failed to close all remote connections")
         if error != 130:
             # keep the tempdir around when a user issues a keyboard interrupt
             # like we do for report
@@ -532,7 +562,7 @@ class SoSCollector(SoSComponent):
         """
         self.commons = {
             'cmdlineopts': self.opts,
-            'need_sudo': True if self.opts.ssh_user != 'root' else False,
+            'need_sudo': self.opts.ssh_user != 'root',
             'tmpdir': self.tmpdir,
             'hostlen': max(len(self.opts.primary), len(self.hostname)),
             'policy': self.policy
@@ -564,15 +594,15 @@ class SoSCollector(SoSComponent):
         if self.opts.cluster_options:
             for opt in self.opts.cluster_options:
                 match = False
-                for clust in self.clusters:
-                    for option in self.clusters[clust].options:
+                for clust, value in self.clusters.items():
+                    for option in value.options:
                         if opt.name == option.name and opt.cluster == clust:
                             match = True
                             opt.value = self._validate_option(option, opt)
                             break
             if not match:
-                self.exit('Unknown cluster option provided: %s.%s'
-                          % (opt.cluster, opt.name), 1)
+                self.exit('Unknown cluster option provided: '
+                          f'{opt.cluster}.{opt.name}', 1)
 
     def _validate_option(self, default, cli):
         """Checks to make sure that the option given on the CLI is valid.
@@ -587,17 +617,13 @@ class SoSCollector(SoSComponent):
                 msg = "Invalid option type for %s. Expected %s got %s"
                 self.exit(msg % (cli.name, default.opt_type, cli.opt_type), 1)
             return cli.value
-        else:
-            val = cli.value.lower()
-            if val not in ['true', 'on', 'yes', 'false', 'off', 'no']:
-                msg = ("Invalid value for %s. Accepted values are: 'true', "
-                       "'false', 'on', 'off', 'yes', 'no'.")
-                self.exit(msg % cli.name, 1)
-            else:
-                if val in ['true', 'on', 'yes']:
-                    return True
-                else:
-                    return False
+
+        val = cli.value.lower()
+        if val not in ['true', 'on', 'yes', 'false', 'off', 'no']:
+            msg = ("Invalid value for %s. Accepted values are: 'true', "
+                   "'false', 'on', 'off', 'yes', 'no'.")
+            self.exit(msg % cli.name, 1)
+        return val in ['true', 'on', 'yes']
 
     def log_info(self, msg):
         """Log info messages to both console and log file"""
@@ -614,7 +640,7 @@ class SoSCollector(SoSComponent):
     def log_debug(self, msg):
         """Log debug message to both console and log file"""
         caller = inspect.stack()[1][3]
-        msg = '[sos_collector:%s] %s' % (caller, msg)
+        msg = f'[sos_collector:{caller}] {msg}'
         self.soslog.debug(msg)
 
     def list_options(self):
@@ -625,13 +651,13 @@ class SoSCollector(SoSComponent):
         sys.stdout.write('Use the short name with --cluster-type or cluster '
                          'options (-c)\n\n')
         for cluster in sorted(self.clusters):
-            sys.stdout.write(" {:<15} {:30}\n".format(
-                                cluster,
-                                self.clusters[cluster].cluster_name))
+            sys.stdout.write(
+                f" {cluster:<15} {self.clusters[cluster].cluster_name:30}\n"
+            )
 
         _opts = {}
-        for _cluster in self.clusters:
-            for opt in self.clusters[_cluster].options:
+        for _, value in self.clusters.items():
+            for opt in value.options:
                 if opt.name not in _opts.keys():
                     _opts[opt.name] = opt
                 else:
@@ -640,51 +666,47 @@ class SoSCollector(SoSComponent):
                             _opts[opt.name].cluster.append(clust)
 
         sys.stdout.write('\nThe following cluster options are available:\n\n')
-        sys.stdout.write(' {:25} {:15} {:<10} {:10} {:<}\n'.format(
-            'Cluster',
-            'Option Name',
-            'Type',
-            'Default',
-            'Description'
-        ))
+        sys.stdout.write(
+            f" {'Cluster':25} {'Option Name':15} {'Type':<10} {'Default':10} "
+            f"{'Description':<}\n"
+        )
 
         for _opt in sorted(_opts, key=lambda x: _opts[x].cluster):
             opt = _opts[_opt]
-            optln = ' {:25} {:15} {:<10} {:<10} {:<10}\n'.format(
-                ', '.join(c for c in sorted(opt.cluster)),
-                opt.name,
-                opt.opt_type.__name__,
-                str(opt.value),
-                opt.description)
+            optln = (
+                f"  {', '.join(c for c in sorted(opt.cluster)):25} "
+                f"{opt.name:15} {opt.opt_type.__name__:<10} "
+                f"{str(opt.value):<10} {opt.description:<10}\n"
+            )
             sys.stdout.write(optln)
         sys.stdout.write('\nOptions take the form of cluster.name=value'
                          '\nE.G. "ovirt.no-database=True" or '
                          '"pacemaker.offline=False"\n')
 
     def delete_tmp_dir(self):
-        """Removes the temp directory and all collected sosreports"""
+        """Removes the temp directory and all collected sos reports"""
         shutil.rmtree(self.tmpdir)
 
     def _get_archive_name(self):
         """Generates a name for the tarball archive"""
         nstr = 'sos-collector'
         if self.opts.label:
-            nstr += '-%s' % self.opts.label
+            nstr += f'-{self.opts.label}'
         if self.opts.case_id:
-            nstr += '-%s' % self.opts.case_id
+            nstr += f'-{self.opts.case_id}'
         dt = datetime.strftime(datetime.now(), '%Y-%m-%d')
 
         try:
             string.lowercase = string.ascii_lowercase
-        except NameError:
-            pass
+        except NameError as err:
+            self.log_debug(f"Could not cast to ascii_lowercase: {err}")
 
         rand = ''.join(random.choice(string.lowercase) for x in range(5))
-        return '%s-%s-%s' % (nstr, dt, rand)
+        return f'{nstr}-{dt}-{rand}'
 
     def _get_archive_path(self):
         """Returns the path, including filename, of the tarball we build
-        that contains the collected sosreports
+        that contains the collected sos reports
         """
         self.arc_name = self._get_archive_name()
         compr = 'gz'
@@ -710,7 +732,7 @@ class SoSCollector(SoSComponent):
         grp = self.opts.group
         paths = [
             grp,
-            os.path.join(Path.home(), '.config/sos/groups.d/%s' % grp),
+            os.path.join(Path.home(), f'.config/sos/groups.d/{grp}'),
             os.path.join(COLLECTOR_CONFIG_DIR, grp)
         ]
 
@@ -720,34 +742,34 @@ class SoSCollector(SoSComponent):
                 fname = path
                 break
         if fname is None:
-            raise OSError("no group definition for %s" % grp)
+            raise OSError(f"no group definition for {grp}")
 
-        self.log_debug("Loading host group %s" % fname)
+        self.log_debug(f"Loading host group {fname}")
 
-        with open(fname, 'r') as hf:
+        with open(fname, 'r', encoding='utf-8') as hf:
             _group = json.load(hf)
             for key in ['primary', 'cluster_type']:
                 if _group[key]:
-                    self.log_debug("Setting option '%s' to '%s' per host group"
-                                   % (key, _group[key]))
+                    self.log_debug(f"Setting option '{key}' to '{_group[key]}'"
+                                   "per host group")
                     setattr(self.opts, key, _group[key])
             if _group['nodes']:
-                self.log_debug("Adding %s to node list" % _group['nodes'])
+                self.log_debug(f"Adding {_group['nodes']} to node list")
                 self.opts.nodes.extend(_group['nodes'])
 
     def write_host_group(self):
         """
-        Saves the results of this run of sos-collector to a host group file
+        Saves the results of this run of sos collect to a host group file
         on the system so it can be used later on.
 
         The host group will save the options primary, cluster_type, and nodes
-        as determined by sos-collector prior to execution of sosreports.
+        as determined by sos collect prior to execution of sos reports.
         """
         cfg = {
             'name': self.opts.save_group,
             'primary': self.opts.primary,
             'cluster_type': self.cluster.cluster_type[0],
-            'nodes': [n for n in self.node_list]
+            'nodes': list(self.node_list)
         }
         if os.getuid() != 0:
             group_path = os.path.join(Path.home(), '.config/sos/groups.d')
@@ -756,7 +778,7 @@ class SoSCollector(SoSComponent):
         else:
             group_path = COLLECTOR_CONFIG_DIR
         fname = os.path.join(group_path, cfg['name'])
-        with open(fname, 'w') as hf:
+        with open(fname, 'w', encoding='utf-8') as hf:
             json.dump(cfg, hf)
         os.chmod(fname, 0o600)
         return fname
@@ -766,7 +788,7 @@ class SoSCollector(SoSComponent):
         if (not self.opts.password and not
                 self.opts.password_per_node):
             self.log_debug('password not specified, assuming SSH keys')
-            msg = ('sos-collector ASSUMES that SSH keys are installed on all '
+            msg = ('sos collect ASSUMES that SSH keys are installed on all '
                    'nodes unless the --password option is provided.\n')
             self.ui_log.info(self._fmt_msg(msg))
 
@@ -775,8 +797,8 @@ class SoSCollector(SoSComponent):
                                         self.opts.primary))
                     and not self.opts.batch):
                 self.log_debug('password specified, not using SSH keys')
-                msg = ('Provide the SSH password for user %s: '
-                       % self.opts.ssh_user)
+                msg = ('Provide the SSH password for user '
+                       f'{self.opts.ssh_user}: ')
                 self.opts.password = getpass(prompt=msg)
 
             if ((self.commons['need_sudo'] and not self.opts.nopasswd_sudo)
@@ -785,8 +807,8 @@ class SoSCollector(SoSComponent):
                     self.log_debug('non-root user specified, will request '
                                    'sudo password')
                     msg = ('A non-root user has been provided. Provide sudo '
-                           'password for %s on remote nodes: '
-                           % self.opts.ssh_user)
+                           f'password for {self.opts.ssh_user} on remote '
+                           'nodes: ')
                     self.opts.sudo_pw = getpass(prompt=msg)
                 else:
                     if not self.opts.nopasswd_sudo:
@@ -802,8 +824,8 @@ class SoSCollector(SoSComponent):
                            "to become root remotely.")
                     self.exit(msg, 1)
                 self.log_debug('non-root user asking to become root remotely')
-                msg = ('User %s will attempt to become root. '
-                       'Provide root password: ' % self.opts.ssh_user)
+                msg = (f'User {self.opts.ssh_user} will attempt to become '
+                       'root. Provide root password: ')
                 self.opts.root_password = getpass(prompt=msg)
                 self.commons['need_sudo'] = False
             else:
@@ -815,8 +837,8 @@ class SoSCollector(SoSComponent):
             try:
                 self._load_group_config()
             except Exception as err:
-                msg = ("Could not load specified group %s: %s"
-                       % (self.opts.group, err))
+                msg = (f"Could not load specified group {self.opts.group}: "
+                       f"{err}")
                 self.exit(msg, 1)
 
         try:
@@ -856,8 +878,8 @@ class SoSCollector(SoSComponent):
                                        local_sudo=local_sudo,
                                        load_facts=can_run_local)
             except Exception as err:
-                self.log_debug("Unable to determine local installation: %s" %
-                               err)
+                self.log_debug("Unable to determine local installation: "
+                               f"{err}")
                 self.exit('Unable to determine local installation. Use the '
                           '--no-local option if localhost should not be '
                           'included.\nAborting...\n', 1)
@@ -896,8 +918,9 @@ class SoSCollector(SoSComponent):
             self.cluster.setup()
             if self.cluster.cluster_ssh_key:
                 if not self.opts.ssh_key:
-                    self.log_debug("Updating SSH key to %s per cluster"
-                                   % self.cluster.cluster_ssh_key)
+                    self.log_debug(
+                        f"Updating SSH key to {self.cluster.cluster_ssh_key} "
+                        "per cluster")
                     self.opts.ssh_key = self.cluster.cluster_ssh_key
 
         self.get_nodes()
@@ -905,9 +928,9 @@ class SoSCollector(SoSComponent):
             gname = self.opts.save_group
             try:
                 fname = self.write_host_group()
-                self.log_info("Wrote group '%s' to %s" % (gname, fname))
+                self.log_info(f"Wrote group '{gname}' to {fname}")
             except Exception as err:
-                self.log_error("Could not save group %s: %s" % (gname, err))
+                self.log_error(f"Could not save group {gname}: {err}")
 
     def display_nodes(self):
         """Prints a list of nodes to collect from, if available. If no nodes
@@ -923,11 +946,12 @@ class SoSCollector(SoSComponent):
         if self.primary.connected and self.primary.hostname is not None:
             if not ((self.primary.local and self.opts.no_local)
                     or self.cluster.strict_node_list):
-                self.ui_log.info('\t%-*s' % (self.commons['hostlen'],
-                                             self.primary.hostname))
+                self.ui_log.info(
+                    f"\t{self.primary.hostname:<{self.commons['hostlen']}}"
+                )
 
         for node in sorted(self.node_list):
-            self.ui_log.info("\t%-*s" % (self.commons['hostlen'], node))
+            self.ui_log.info(f"\t{node:<{self.commons['hostlen']}}")
 
         self.ui_log.info('')
         if not self.opts.batch:
@@ -941,7 +965,7 @@ class SoSCollector(SoSComponent):
                 self.exit(repr(e), 1)
 
     def configure_sos_cmd(self):
-        """Configures the sosreport command that is run on the nodes"""
+        """Configures the sos report command that is run on the nodes"""
         sos_cmd = 'sosreport --batch '
 
         sos_options = {}
@@ -977,10 +1001,10 @@ class SoSCollector(SoSComponent):
         """
         try:
             self.primary = SosNode(self.opts.primary, self.commons)
-            self.ui_log.info('Connected to %s, determining cluster type...'
-                             % self.opts.primary)
+            self.ui_log.info(f'Connected to {self.opts.primary}, determining '
+                             'cluster type...')
         except Exception as e:
-            self.log_debug('Failed to connect to primary node: %s' % e)
+            self.log_debug(f'Failed to connect to primary node: {e}')
             self.exit('Could not connect to primary node. Aborting...', 1)
 
     def determine_cluster(self):
@@ -998,34 +1022,33 @@ class SoSCollector(SoSComponent):
             cluster.primary = self.primary
             if cluster.check_enabled():
                 cname = cluster.__class__.__name__
-                self.log_debug("Installation matches %s, checking for layered "
-                               "profiles" % cname)
+                self.log_debug(f"Installation matches {cname}, checking for "
+                               "layered profiles")
                 for remaining in checks:
                     if issubclass(remaining.__class__, cluster.__class__):
                         rname = remaining.__class__.__name__
-                        self.log_debug("Layered profile %s found. "
-                                       "Checking installation"
-                                       % rname)
+                        self.log_debug(f"Layered profile {rname} found. "
+                                       "Checking installation")
                         remaining.primary = self.primary
                         if remaining.check_enabled():
                             self.log_debug("Installation matches both layered "
-                                           "profile %s and base profile %s, "
-                                           "setting cluster type to layered "
-                                           "profile" % (rname, cname))
+                                           f"profile {rname} and base profile "
+                                           f"{cname}, setting cluster type to "
+                                           "layered profile")
                             cluster = remaining
                             break
                 self.cluster = cluster
                 self.cluster_type = cluster.name()
                 self.commons['cluster'] = self.cluster
                 self.ui_log.info(
-                    'Cluster type set to %s' % self.cluster_type)
+                    f'Cluster type set to {self.cluster_type}')
                 break
 
     def get_nodes_from_cluster(self):
         """Collects the list of nodes from the determined cluster cluster"""
         if self.cluster_type:
             nodes = self.cluster._get_nodes()
-            self.log_debug('Node list: %s' % nodes)
+            self.log_debug(f'Node list: {nodes}')
             return nodes
         return []
 
@@ -1042,10 +1065,10 @@ class SoSCollector(SoSComponent):
         # an open session to it.
         if self.primary is not None and not self.cluster.strict_node_list:
             for n in self.node_list:
-                if n == self.primary.hostname or n == self.opts.primary:
+                if n in (self.primary.hostname, self.opts.primary):
                     self.node_list.remove(n)
         self.node_list = list(set(n for n in self.node_list if n))
-        self.log_debug('Node list reduced to %s' % self.node_list)
+        self.log_debug(f'Node list reduced to {self.node_list}')
         self.collect_md.add_list('node_list', self.node_list)
 
     def compare_node_to_regex(self, node):
@@ -1062,7 +1085,7 @@ class SoSCollector(SoSComponent):
         return False
 
     def get_nodes(self):
-        """ Sets the list of nodes to collect sosreports from """
+        """ Sets the list of nodes to collect sos reports from """
         if not self.primary and not self.cluster:
             msg = ('Could not determine a cluster type and no list of '
                    'nodes or primary node was provided.\nAborting...'
@@ -1078,7 +1101,7 @@ class SoSCollector(SoSComponent):
             else:
                 self.node_list = nodes
         except Exception as e:
-            self.log_debug("Error parsing node list: %s" % e)
+            self.log_debug(f"Error parsing node list: {e}")
             self.log_debug('Setting node list to --nodes option')
             self.node_list = self.opts.nodes
             for node in self.node_list:
@@ -1091,7 +1114,7 @@ class SoSCollector(SoSComponent):
                 if any(i in node for i in '*\\?()/[]'):
                     continue
                 if node not in self.node_list:
-                    self.log_debug("Force adding %s to node list" % node)
+                    self.log_debug(f"Force adding {node} to node list")
                     self.node_list.append(node)
 
         if not self.primary:
@@ -1106,12 +1129,12 @@ class SoSCollector(SoSComponent):
         try:
             _node_max = len(max(self.node_list, key=len))
             self.commons['hostlen'] = max(_node_max, self.commons['hostlen'])
-        except (TypeError, ValueError):
-            pass
+        except (TypeError, ValueError) as err:
+            self.log_debug(f"Could not set UI spacing: {err}")
 
     def _connect_to_node(self, node):
         """Try to connect to the node, and if we can add to the client list to
-        run sosreport on
+        run sos report on
 
         Positional arguments
             node - a tuple specifying (address, password). If no password, set
@@ -1135,7 +1158,7 @@ class SoSCollector(SoSComponent):
         """Print the intro message and prompts for a case ID if one is not
         provided on the command line
         """
-        disclaimer = ("""\
+        disclaimer = """\
 This utility is used to collect sos reports from multiple \
 nodes simultaneously. Remote connections are made and/or maintained \
 to those nodes via well-known transport protocols such as SSH.
@@ -1149,8 +1172,8 @@ organization before being passed to any third party.
 
 No configuration changes will be made to the system running \
 this utility or remote systems that it connects to.
-""")
-        self.ui_log.info("\nsos-collector (version %s)\n" % __version__)
+"""
+        self.ui_log.info(f"\nsos collect (version {__version__})\n")
         intro_msg = self._fmt_msg(disclaimer % self.tmpdir)
         self.ui_log.info(intro_msg)
 
@@ -1185,7 +1208,7 @@ this utility or remote systems that it connects to.
 
     def collect(self):
         """ For each node, start a collection thread and then tar all
-        collected sosreports """
+        collected sos reports """
         filters = set([self.primary.address, self.primary.hostname])
         # add primary if:
         # - we are connected to it and
@@ -1203,8 +1226,8 @@ this utility or remote systems that it connects to.
         if self.opts.password_per_node:
             _nodes = []
             for node in nodes:
-                msg = ("Please enter the password for %s@%s: "
-                       % (self.opts.ssh_user, node[0]))
+                msg = (f"Please enter the password for {self.opts.ssh_user}@"
+                       f"{node[0]}: ")
                 node_pwd = getpass(msg)
                 _nodes.append((node[0], node_pwd))
             nodes = _nodes
@@ -1232,10 +1255,9 @@ this utility or remote systems that it connects to.
                         "Aborting...", 1
                     )
 
-            self.ui_log.info("\nBeginning collection of sosreports from %s "
-                             "nodes, collecting a maximum of %s "
-                             "concurrently\n"
-                             % (self.report_num, self.opts.jobs))
+            self.ui_log.info("\nBeginning collection of sos reports from "
+                             f"{self.report_num} nodes, collecting a maximum "
+                             f"of {self.opts.jobs} concurrently\n")
 
             npool = ThreadPoolExecutor(self.opts.jobs)
             npool.map(self._finalize_sos_cmd, self.client_list, chunksize=1)
@@ -1247,7 +1269,7 @@ this utility or remote systems that it connects to.
         except KeyboardInterrupt:
             self.exit("Exiting on user cancel\n", 130, force=True)
         except Exception as err:
-            msg = 'Could not connect to nodes: %s' % err
+            msg = f'Could not connect to nodes: {err}'
             self.exit(msg, 1, force=True)
 
         if hasattr(self.cluster, 'run_extra_cmd'):
@@ -1255,21 +1277,22 @@ this utility or remote systems that it connects to.
             files = self.cluster._run_extra_cmd()
             if files:
                 self.primary.collect_extra_cmd(files)
-        msg = '\nSuccessfully captured %s of %s sosreports'
+        msg = '\nSuccessfully captured %s of %s sos reports'
         self.log_info(msg % (self.retrieved, self.report_num))
         self.close_all_connections()
         if self.retrieved > 0:
-            arc_name = self.create_cluster_archive()
+            self.arc_name = self.create_cluster_archive()
         else:
-            msg = 'No sosreports were collected, nothing to archive...'
+            msg = 'No sos reports were collected, nothing to archive...'
             self.exit(msg, 1)
 
-        if self.opts.upload and self.policy.get_upload_url():
+        if (self.opts.upload and self.policy.get_upload_url()) or \
+                self.opts.upload_s3_endpoint:
             try:
-                self.policy.upload_archive(arc_name)
+                self.policy.upload_archive(self.arc_name)
                 self.ui_log.info("Uploaded archive successfully")
             except Exception as err:
-                self.ui_log.error("Upload attempt failed: %s" % err)
+                self.ui_log.error(f"Upload attempt failed: {err}")
 
     def _finalize_sos_cmd(self, client):
         """Calls finalize_sos_cmd() on each node so that we have the final
@@ -1278,11 +1301,11 @@ this utility or remote systems that it connects to.
         try:
             client.finalize_sos_cmd()
         except Exception as err:
-            self.log_error("Could not finalize sos command for %s: %s"
-                           % (client.address, err))
+            self.log_error("Could not finalize sos command for "
+                           f"{client.address}: {err}")
 
     def _collect(self, client):
-        """Runs sosreport on each node"""
+        """Runs sos report on each node"""
         try:
             if not client.local:
                 client.sosreport()
@@ -1292,18 +1315,18 @@ this utility or remote systems that it connects to.
             if client.retrieved:
                 self.retrieved += 1
         except Exception as err:
-            self.log_error("Error running sosreport: %s" % err)
+            self.log_error(f"Error running sos report: {err}")
 
     def close_all_connections(self):
         """Close all sessions for nodes"""
         for client in self.client_list:
             if client.connected:
-                self.log_debug('Closing connection to %s' % client.address)
+                self.log_debug(f'Closing connection to {client.address}')
                 client.disconnect()
 
     def create_cluster_archive(self):
         """Calls for creation of tar archive then cleans up the temporary
-        files created by sos-collector"""
+        files created by sos collect"""
         map_file = None
         arc_paths = []
         for host in self.client_list:
@@ -1327,11 +1350,10 @@ this utility or remote systems that it connects to.
                 map_file, arc_paths = cleaner.execute()
                 do_clean = True
             except Exception as err:
-                self.ui_log.error("ERROR: unable to obfuscate reports: %s"
-                                  % err)
+                self.ui_log.error(f"ERROR: unable to obfuscate reports: {err}")
 
         try:
-            self.log_info('Creating archive of sosreports...')
+            self.log_info('Creating archive of sos reports...')
             for fname in arc_paths:
                 dest = fname.split('/')[-1]
                 if do_clean:
@@ -1354,6 +1376,7 @@ this utility or remote systems that it connects to.
                 self.archive.add_final_manifest_data(
                     self.opts.compression_type
                 )
+            self._obfuscate_upload_passwords()
             if do_clean:
                 _dir = os.path.join(self.tmpdir, self.archive._name)
                 cleaner.obfuscate_file(
@@ -1382,18 +1405,20 @@ this utility or remote systems that it connects to.
                 # the temp dir it was constructed in
                 map_name = cleaner.obfuscate_string(
                     os.path.join(self.sys_tmp,
-                                 "%s_private_map" % self.archive_name)
+                                 f"{self.archive_name}_private_map")
                 )
                 os.rename(map_file, map_name)
                 self.ui_log.info("A mapping of obfuscated elements is "
-                                 "available at\n\t%s" % map_name)
+                                 f"available at\n\t{map_name}")
 
-            self.soslog.info('Archive created as %s' % final_name)
+            self.soslog.info(f'Archive created as {final_name}')
             self.ui_log.info('\nThe following archive has been created. '
                              'Please provide it to your support team.')
-            self.ui_log.info('\t%s\n' % final_name)
+            self.ui_log.info(f'\t{final_name}\n')
             return final_name
         except Exception as err:
-            msg = ("Could not finalize archive: %s\n\nData may still be "
-                   "available uncompressed at %s" % (err, self.archive_path))
+            msg = (f"Could not finalize archive: {err}\n\nData may still be "
+                   f"available uncompressed at {self.archive_path}")
             self.exit(msg, 2)
+            # Never gets here. This is to fix "inconsistent-return-statements
+            return "Archive error"
