@@ -33,7 +33,7 @@ class AmazonPolicy(RedHatPolicy):
         if not os.path.exists(OS_RELEASE):
             return False
 
-        with open(OS_RELEASE, 'r') as f:
+        with open(OS_RELEASE, 'r', encoding='utf-8') as f:
             for line in f:
                 if line.startswith('NAME'):
                     if 'Amazon Linux' in line:
